@@ -43,7 +43,10 @@
 // DESCRIPTION file) and/or defining #define-ing ARMA_USE_CXX11_RNG
 #define ARMA_RNG_ALT         RcppArmadillo/Alt_R_RNG.h
 
-#include <armadillo>
+// workaround to mitigate possible interference from a system-level installation of Armadillo
+#define ARMA_DONT_USE_WRAPPER
+
+#include "armadillo"
 
 /* forward declarations */
 namespace Rcpp {
