@@ -31,12 +31,17 @@ class Col : public Mat<eT>
   static constexpr bool is_row  = false;
   static constexpr bool is_xvec = false;
   
-  inline          Col();
-  inline          Col(const Col<eT>& X);
+  inline Col();
+  inline Col(const Col<eT>& X);
+  
   inline explicit Col(const uword n_elem);
   inline explicit Col(const uword in_rows, const uword in_cols);
   inline explicit Col(const SizeMat& s);
   
+  template<bool do_zeros> inline explicit Col(const uword n_elem,                       const arma_initmode_indicator<do_zeros>&);
+  template<bool do_zeros> inline explicit Col(const uword in_rows, const uword in_cols, const arma_initmode_indicator<do_zeros>&);
+  template<bool do_zeros> inline explicit Col(const SizeMat& s,                         const arma_initmode_indicator<do_zeros>&);
+  
   template<typename fill_type> inline Col(const uword n_elem,                       const fill::fill_class<fill_type>& f);
   template<typename fill_type> inline Col(const uword in_rows, const uword in_cols, const fill::fill_class<fill_type>& f);
   template<typename fill_type> inline Col(const SizeMat& s,                         const fill::fill_class<fill_type>& f);
@@ -77,7 +82,7 @@ class Col : public Mat<eT>
   inline            Col(const subview_cube<eT>& X);
   inline Col& operator=(const subview_cube<eT>& X);
   
-  inline mat_injector<Col> operator<<(const eT val);
+  arma_cold inline mat_injector<Col> operator<<(const eT val);
   
   arma_inline const Op<Col<eT>,op_htrans>  t() const;
   arma_inline const Op<Col<eT>,op_htrans> ht() const;
