@@ -24,24 +24,23 @@ arma_inline
 void
 arrayops::copy(eT* dest, const eT* src, const uword n_elem)
   {
-  if(dest != src)
+  if( (dest == src) || (n_elem == 0) )  { return; }
+  
+  if(is_cx<eT>::no)
     {
-    if(is_cx<eT>::no)
+    if(n_elem <= 9)
       {
-      if(n_elem <= 9)
-        {
-        arrayops::copy_small(dest, src, n_elem);
-        }
-      else
-        {
-        std::memcpy(dest, src, n_elem*sizeof(eT));
-        }
+      arrayops::copy_small(dest, src, n_elem);
       }
     else
       {
-      if(n_elem > 0)  { std::memcpy(dest, src, n_elem*sizeof(eT)); }
+      std::memcpy(dest, src, n_elem*sizeof(eT));
       }
     }
+  else
+    {
+    std::memcpy(dest, src, n_elem*sizeof(eT));
+    }
   }
 
 
@@ -85,9 +84,11 @@ arrayops::fill_zeros(eT* dest, const uword n_elem)
   {
   typedef typename get_pod_type<eT>::result pod_type;
   
+  if(n_elem == 0)  { return; }
+  
   if(std::numeric_limits<eT>::is_integer || std::numeric_limits<pod_type>::is_iec559)
     {
-    if(n_elem > 0)  { std::memset((void*)dest, 0, sizeof(eT)*n_elem); }
+    std::memset((void*)dest, 0, sizeof(eT)*n_elem);
     }
   else
     {
@@ -174,6 +175,52 @@ arrayops::clean(std::complex<T>* mem, const uword n_elem, const T abs_limit)
 
 
 
+template<typename eT>
+inline
+void
+arrayops::clamp(eT* mem, const uword n_elem, const eT min_val, const eT max_val, const typename arma_not_cx<eT>::result* junk)
+  {
+  arma_ignore(junk);
+  
+  for(uword i=0; i<n_elem; ++i)
+    {
+    eT& val = mem[i];
+    
+    val = (val < min_val) ? min_val : ((val > max_val) ? max_val : val);
+    }
+  }
+
+
+
+template<typename T>
+inline
+void
+arrayops::clamp(std::complex<T>* mem, const uword n_elem, const std::complex<T>& min_val, const std::complex<T>& max_val)
+  {
+  typedef typename std::complex<T> eT;
+  
+  const T min_val_real = std::real(min_val);
+  const T min_val_imag = std::imag(min_val);
+  
+  const T max_val_real = std::real(max_val);
+  const T max_val_imag = std::imag(max_val);
+  
+  for(uword i=0; i<n_elem; ++i)
+    {
+    eT& val = mem[i];
+    
+    T val_real = std::real(val);
+    T val_imag = std::imag(val);
+    
+    val_real = (val_real < min_val_real) ? min_val_real : ((val_real > max_val_real) ? max_val_real : val_real);
+    val_imag = (val_imag < min_val_imag) ? min_val_imag : ((val_imag > max_val_imag) ? max_val_imag : val_imag);
+    
+    val = std::complex<T>(val_real,val_imag);
+    }
+  }
+
+
+
 template<typename out_eT, typename in_eT>
 arma_inline
 void
