@@ -55,8 +55,6 @@ class diskio
   template<typename eT> inline static bool convert_token(eT&              val, const std::string& token);
   template<typename  T> inline static bool convert_token(std::complex<T>& val, const std::string& token);
   
-  template<typename eT> arma_deprecated inline static bool convert_naninf(eT& val, const std::string& token);
-  
   template<typename eT> inline static std::streamsize prepare_stream(std::ostream& f);
   
   
@@ -67,6 +65,7 @@ class diskio
   template<typename eT> inline static bool save_raw_binary (const Mat<eT>&                x, const std::string& final_name);
   template<typename eT> inline static bool save_arma_ascii (const Mat<eT>&                x, const std::string& final_name);
   template<typename eT> inline static bool save_csv_ascii  (const Mat<eT>&                x, const std::string& final_name, const field<std::string>& header, const bool with_header);
+  template<typename eT> inline static bool save_coord_ascii(const Mat<eT>&                x, const std::string& final_name);
   template<typename eT> inline static bool save_arma_binary(const Mat<eT>&                x, const std::string& final_name);
   template<typename eT> inline static bool save_pgm_binary (const Mat<eT>&                x, const std::string& final_name);
   template<typename  T> inline static bool save_pgm_binary (const Mat< std::complex<T> >& x, const std::string& final_name);
@@ -77,6 +76,8 @@ class diskio
   template<typename eT> inline static bool save_arma_ascii (const Mat<eT>&                x, std::ostream& f);
   template<typename eT> inline static bool save_csv_ascii  (const Mat<eT>&                x, std::ostream& f);
   template<typename  T> inline static bool save_csv_ascii  (const Mat< std::complex<T> >& x, std::ostream& f);
+  template<typename eT> inline static bool save_coord_ascii(const Mat<eT>&                x, std::ostream& f);
+  template<typename  T> inline static bool save_coord_ascii(const Mat< std::complex<T> >& x, std::ostream& f);
   template<typename eT> inline static bool save_arma_binary(const Mat<eT>&                x, std::ostream& f);
   template<typename eT> inline static bool save_pgm_binary (const Mat<eT>&                x, std::ostream& f);
   template<typename  T> inline static bool save_pgm_binary (const Mat< std::complex<T> >& x, std::ostream& f);
@@ -89,6 +90,7 @@ class diskio
   template<typename eT> inline static bool load_raw_binary (Mat<eT>&                x, const std::string& name, std::string& err_msg);
   template<typename eT> inline static bool load_arma_ascii (Mat<eT>&                x, const std::string& name, std::string& err_msg);
   template<typename eT> inline static bool load_csv_ascii  (Mat<eT>&                x, const std::string& name, std::string& err_msg, field<std::string>& header, const bool with_header);
+  template<typename eT> inline static bool load_coord_ascii(Mat<eT>&                x, const std::string& name, std::string& err_msg);
   template<typename eT> inline static bool load_arma_binary(Mat<eT>&                x, const std::string& name, std::string& err_msg);
   template<typename eT> inline static bool load_pgm_binary (Mat<eT>&                x, const std::string& name, std::string& err_msg);
   template<typename  T> inline static bool load_pgm_binary (Mat< std::complex<T> >& x, const std::string& name, std::string& err_msg);
@@ -100,6 +102,8 @@ class diskio
   template<typename eT> inline static bool load_arma_ascii (Mat<eT>&                x, std::istream& f,  std::string& err_msg);
   template<typename eT> inline static bool load_csv_ascii  (Mat<eT>&                x, std::istream& f,  std::string& err_msg);
   template<typename  T> inline static bool load_csv_ascii  (Mat< std::complex<T> >& x, std::istream& f,  std::string& err_msg);
+  template<typename eT> inline static bool load_coord_ascii(Mat<eT>&                x, std::istream& f,  std::string& err_msg);
+  template<typename  T> inline static bool load_coord_ascii(Mat< std::complex<T> >& x, std::istream& f,  std::string& err_msg);
   template<typename eT> inline static bool load_arma_binary(Mat<eT>&                x, std::istream& f,  std::string& err_msg);
   template<typename eT> inline static bool load_pgm_binary (Mat<eT>&                x, std::istream& is, std::string& err_msg);
   template<typename  T> inline static bool load_pgm_binary (Mat< std::complex<T> >& x, std::istream& is, std::string& err_msg);
