@@ -26,15 +26,18 @@ op_cond::cond(const Base<typename T1::elem_type, T1>& X)
   {
   arma_extra_debug_sigprint();
   
-  typedef typename T1::pod_type T;
+  typedef typename T1::elem_type eT;
+  typedef typename T1::pod_type   T;
+  
+  Mat<eT> A(X.get_ref());
   
   Col<T> S;
   
-  const bool status = auxlib::svd_dc(S, X);
+  const bool status = auxlib::svd_dc(S, A);
   
   if(status == false)
     {
-    arma_debug_warn("cond(): svd failed");
+    arma_debug_warn_level(3, "cond(): svd failed");
     
     return T(0);
     }
