@@ -70,7 +70,7 @@ op_inv::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename T1::e
   
   if((out.n_rows <= 4) && is_cx<eT>::no)
     {
-    Mat<eT> tmp(out.n_rows, out.n_rows);
+    Mat<eT> tmp(out.n_rows, out.n_rows, arma_nozeros_indicator());
     
     const bool status = op_inv::apply_tiny_noalias(tmp, out);
     
@@ -144,7 +144,7 @@ op_inv::apply_diagmat(Mat<typename T1::elem_type>& out, const T1& X, const char*
     }
   else
     {
-    Mat<eT> tmp(N, N, fill::zeros);
+    Mat<eT> tmp(N, N, arma_zeros_indicator());
     
     for(uword i=0; i<N; ++i)
       {
@@ -317,7 +317,7 @@ op_inv_sympd::apply_direct(Mat<typename T1::elem_type>& out, const Base<typename
   
   if((out.n_rows <= 4) && is_cx<eT>::no)
     {
-    Mat<eT> tmp(out.n_rows, out.n_rows);
+    Mat<eT> tmp(out.n_rows, out.n_rows, arma_nozeros_indicator());
     
     const bool status = op_inv::apply_tiny_noalias(tmp, out);
     
